# Application for HPC Resources

##### This section provides you with guidelines how to  
- apply for resources to use the HPC system -> [application workflow](./project_request_form.md)  
- manage members and their access to the project -> [User management for project leaders](./project_management.md)  
<br>
##### Below you will find the information about:

- [NHR-center](#nhr-center)
- [Acknowledgment in Publications](#acknowledgment-in-publications)
- [Terms of Use](#terms-of-use)



## NHR-center
In order to use the HPC systems installed at ZIH, it is necessary to apply for the resources.
The applicant (HPC project manager) is required to have a doctorate/PhD.  
It is possible to apply to different [project types](./project_request_form.md) depending on the project requirements. 

However, the [application workflow](./project_request_form.md) is for all types identical.

Since 2021, HPC at universities has been restructured by the [NHR network](https://www.nhr-verein.de/).
The network consists of nine centers, which operate the systems and offer
a coordinated consulting service on the methodological competence of scientific HPC.
The aim is to provide scientists at German universities with computing capacity
for their research and to strengthen their skills in the efficient use of this resource.


!!! Info  "Researchers with a doctorate from universities or universities of applied sciences in Germany are eligible to apply"  
      
    We particularly invite researchers to apply with
     research projects related to our focus topics:  

       * Life Sciences
       * Earth System Science
       * Methods for big data and data analysis and
        management
       * Machine Learning
       * Tiered storage architectures and I/O optimization
       * Performance and energy efficiency analysis and 
       optimization
       * Research projects not related to our focus topics 
       but from Universities within Saxony.

    We recommend **all other researchers** to review the
     focus topics of the remaining 
    [NHR centers](https://www.nhr-verein.de/anwendungsunterstuetzung) and apply to the most suitable for
     your research topic.  
    Working at the specialized NHR center related to your 
    research topic, provides you with the advantage of 
    receiving topic specific support.


## Acknowledgment in Publications

To provide you with modern and powerful HPC systems in future as well, we have to show that these
systems help to advance research. For that purpose we rely on your help. In most cases, the results
of your computations are used for presentations and publications, especially in peer-reviewed
magazines, journals, and conference proceedings. We kindly ask you to mention the HPC resource usage
in the acknowledgment section of all publications that are based on granted HPC resources of the
[NHR-center at TU Dresden][4]. 

We kindly ask you to mention the HPC resource usage in the acknowledgment section of all
publications that are based on granted HPC resources of the TU Dresden.

We provide some acknowledgment examples below.  
<br>

**Examples:**

??? note "Standard case"

    The authors gratefully acknowledge the computing time
    made available to them on
    the high-performance computer <XY> at the NHR Center of
    TU Dresden. This center is jointly
    supported by the Federal Ministry of Education and
    Research and the state governments
    participating in the NHR 
    (www.nhr-verein.de/  unsere-partner).


??? note "Two NHR centers"

    The authors gratefully acknowledge the computing time
    made available to them on
    the high-performance computers <XY> and <YZ> at the NHR
    Centers at TU Dresden and <YZ>.
    These centers are jointly supported by the Federal 
    Ministry of Education and Research
    and the state governments participating in the NHR
    (www.nhr-verein.de/unsere-partner).


??? note "German"

    Die Autoren bedanken sich für die ihnen zur Verfügung
    gestellte Rechenzeit auf
    dem Hochleistungsrechner <XY> am NHR-Zentrum der TU 
    Dresden. Dieses wird gemeinsam durch
    das Bundesministerium für Bildung und Forschung und den
    am NHR beteiligten
    Landesregierungen (www.nhr-verein.de/unsere-partner) 
    unterstützt.


## Terms of Use


!!! attention

    Only the German version of the *Terms of Use* is binding.

These new Terms of Use are valid from April 1, 2018: [HPC-Nutzungsbedingungen_20180305.pdf][1]

The key points are are:

- For support reasons, we store your contact data according to our [identity management system][9].
  (Will be anonymized at least 15 months after the cancellation of the HPC login.)
  The data of the HPC project (incl. contact of project leader) will be kept for
  further reference.
    -Our HPC resources may only be used according to the project description.
- Responsibilities for the project leader:
    - She has to assign a team member with an HPC login as the technical project
      administrator. She can do this herself if she has a login at our systems.
    - The project leader or the administrator will have to add/remove members to
      their project. She has access to accounting data for her project.
- These issues cover the data storage in our systems:
    - Please work in the scratch filesystems.
    - Upon request, the project leader or the administrator can be given access
      to a user's directory.
    - The scratch filesystems (`/tmp`, `/scratch`, `/lustre/ssd`) are for
      temporary use only. After a certain time, files may be removed
      automatically (for `/tmp` after 7 days, parallel `/scratch`: after 100 days).
    - Before a user leaves a project the leader/administrator has to store away
      worthy data. For this, the storage services of ZIH (long term storage,
      intermediate archive) can be used.
- Project termination (**new**)
    - At project's end, jobs cannot be submitted and started any longer.
    - Logins are valid for 30 more days for saving data.
    - Hundred days after project termination, it's files will be deleted in
      the HPC filesystems.
- The HPC user agrees to follow the instructions and hints of the support
  team. In case of non-compliance, she can be disabled for the batch system
  or banned from the system.

- Working with logs and HPC performance data (**new**)
    - For HPC related research ZIH will collect and analyze
      performance data. Anonymized, it might be shared with research partners.
    - Log data will be kept for long term analyzes.

These key points are only a brief summary. If in doubt, please consult the German original.

## History

| Valid                           | Document                                     |
|:--------------------------------|:---------------------------------------------|
| 1 April 2018 -                  | [HPC-Nutzungsbedingungen_20180305.pdf][5]    |
| 1 October 2016 - 31 March 2018  | [HPC-Nutzungsbedingungen_20160901.pdf][6]    |
| 5 June 2014 - 30 September 2016 | [HPC-Nutzungsbedingungen_20140606.pdf][7]    |

- Not binding translation in english: [Terms-of-use-HPC-20180305-engl.pdf][8]




[1]: https://tu-dresden.de/zih/hochleistungsrechnen/zugang
[2]: https://selfservice.zih.tu-dresden.de/index.php/hpclogin/noLogin
[3]: https://selfservice.zih.tu-dresden.de/l/index.php/hpclogin
[4]: https://tu-dresden.de/zih/hochleistungsrechnen/nhr-center
[5]: ./misc/HPC-Nutzungsbedingungen_20180305.pdf
[6]: ./misc/HPC-Nutzungsbedingungen_20160901.pdf
[7]: ./misc/HPC-Nutzungsbedingungen_20140606.pdf
[8]: ./misc/Terms-of-use-HPC-20180305-engl.pdf
[9]: https://tu-dresden.de/zih/dienste/service-katalog/zugangsvoraussetzung
